#
# spec file for package pcsc-tools
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pcsc-tools
Version:        1.7.1
Release:        1.3
Summary:        Smart card tools
License:        GPL-2.0-or-later
Group:          System/Management
URL:            https://pcsc-tools.apdu.fr/
Source0:        https://pcsc-tools.apdu.fr/%{name}-%{version}.tar.bz2
Source1:        https://pcsc-tools.apdu.fr/%{name}-%{version}.tar.bz2.asc
Source2:        pcsc-tools.keyring
BuildRequires:  pcsc-lite-devel
BuildRequires:  pkgconfig
Requires:       perl-pcsc
Requires:       perl(Glib)
Requires:       perl(Gtk3)

%description
These tools are used to test a PC/SC driver, card or reader
or send commands in a friendly environment
(text or graphical user interface).

%prep
%autosetup -p1
sed 's|#!/usr/bin/env perl|#!/usr/bin/perl|g' -i ATR_analysis.in gscriptor scriptor

%build
%configure
%make_build

%install
%make_install

%files
%license LICENCE
%doc Changelog README
%{_bindir}/ATR_analysis
%{_bindir}/gscriptor
%{_bindir}/pcsc_scan
%{_bindir}/scriptor
%{_datadir}/pcsc/
%{_mandir}/man1/*
%{_datadir}/applications/gscriptor.desktop
%{_datadir}/locale/fr/LC_MESSAGES/pcsc-tools.mo
%{_datadir}/locale/ru/LC_MESSAGES/pcsc-tools.mo

%changelog
* Sun Feb 11 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.7.1:
  * New ATRs
  * build system changes and developer visible fixes
* Mon Nov 27 2023 Wang Jun <badboywj@gmail.com>
- update to 1.7.0:
  * 182 new ATRs
  * pcsc_scan:
    + add debug option -d
    + add PnP option -p
  * gscriptor: i18n and l10n in English (default), French
    and Russian
  * configure: add --enable-ATRparser=foobar to specify an
    ATR parser
  * minor fixes and improvements
* Sun May  7 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- update to 1.6.2:
  * ATR_analysis: URL updates
  * new ATRs
  * LICENCE file now packaged
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.6.1:
  * Fix Hungarian eID URL
  * New ATR for OTP Bank Mastercard
  * new ATRs
  * pcsc_scan: add "wsvt25" as a color terminal
* Thu Oct 20 2022 Antonio Larrosa <alarrosa@suse.com>
- Replace the requirement for perl(Gtk2) with perl(Gtk3) which is
  what's actually used.
* Sun Jan 30 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.6.0
  * 48 new ATRs
  * pcsc_scan:
  + drastically reduce the number of SCardGetStatusChange() calls
  + faster spinning animation
* Mon Nov  8 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.8
  * 360 new ATRs
  * ATR_analysis:
    + fix TB2 parsing error
    + misc spelling fixes
  * pcsc_scan:
    + add maxtime option -t
    + add the option -c to list cards only once
    + no spinner in quiet mode (-q)
    + turn off colour if redirected output
    + Exit if no reader is found and -c or -r is used
- Run spec-cleaner
* Tue Jul  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.7
  * 116 new ATRs
  * ATR_analysis: Update URL of the online parser
- Update to version 1.5.6
  * 62 new ATRs
  * pcsc_scan: better support of Windows
- Update to version 1.5.5
  * 353 new ATRs
  * scriptor: add -u option to make stdout unbuffered
* Mon Aug 19 2019 Wolfgang Rosenauer <wr@rosenauer.org>
- added missing dependencies for gscriptor (boo#1145779)
* Sat Feb  2 2019 Jan Engelhardt <jengelh@inai.de>
- Update summary.
* Tue Jan 29 2019 sbrabec@suse.com
- Update to version 1.5.4:
  * Port to gtk+-3.
  * gscriptor: save and restore the window size, remove
    unimplemented Logo.
  * many new ATRs
  * warning fixes
* Sat Apr 21 2018 wr@rosenauer.org
- update to 1.5.3
  * 253 new ATRs
  * pcsc_scan
  - add -v argument (default) for verbose
  - add -q argument for quiet
  - add -r argument to display the reader list
  - allow to use Control-C to break execution
* Tue Jun 20 2017 astieger@suse.com
- update to 1.5.2:
  * build system updates, now using autoconf/automake
  * many new new ATRs
  * pcsc_scan: various improvements to stress mode
  * documentation updates
  * Handle "simultaneous" readers removal
* Sun Mar 20 2016 wr@rosenauer.org
- Update to version 1.4.26
  * 77 new ATRs
  * ATR_analysis: fix display the submission message
  * fix typos in pcsc_scan.1 and scriptor.1p man pages
* Sun Nov  8 2015 wr@rosenauer.org
- Update to version 1.4.25
  * 44 new ATRs
  * ATR_analysis: fix the update of the local cache
* Sat Aug  8 2015 wr@rosenauer.org
- Update to version 1.4.24
  * 253 new ATRs
  * ATR_analysis: better update of the local cache
* Sat Sep 20 2014 wr@rosenauer.org
- Update to version 1.4.23
  * many new ATRs
- fixed perl-pcsc package name (bnc#897046)
* Fri Jan 17 2014 wr@rosenauer.org
- Update to version 1.4.22:
  * 215 new ATRs
  * Fetch a new ATR file if it was not upgraded in the last 10
    hours.
  * Propose to use http://smartcard-atr.appspot.com/parse to submit a
    new ATR
  * minor fixes
* Mon Oct 14 2013 sbrabec@suse.cz
- Update to version 1.4.21:
  * Minor bug fixes.
  * Many ATRs updates.
- Verify GPG signature.
* Tue Mar 26 2013 hpj@urpla.net
- add missing required package perl-pcsc-perl
* Mon Dec 19 2011 wr@rosenauer.org
- update to 1.4.18
  * gscriptor: Display hex dumps in lines of 16 bytes instead of 17
  * gscriptor: Display bytes of value 0x20 as ' ' instead of '.'
  * scriptor: Display lines of 16 bytes instead of 24
  * 223 new ATRs
  * pcsc_scan: Correctly detect reader Plug and Play support
* Mon May  2 2011 wr@rosenauer.org
- initial openSUSE package
